@@ -62,10 +62,10 @@
 ##'
 ##' ### predictions with CI based on iid decomposition of baseline and beta
 ##' fg <- cifreg(Event(time,cause)~tcell+platelet+age,data=bmt,cause=1,propodds=NULL,cox.prep=TRUE)
-##' Biid <- mets:::iid.baseline.cifreg(fg,time=20)
+##' Biid <- IIDbaseline.cifreg(fg,time=20)
 ##' FGprediid(Biid,bmt[1:5,])
 ##'
-##' @aliases vecAllStrata diffstrata iid.baseline.cifreg FGprediid indexstratarightR
+##' @aliases vecAllStrata diffstrata IIDbaseline.cifreg FGprediid indexstratarightR
 ##' @export
 cifreg <- function(formula,data=data,cause=1,cens.code=0,cens.model=~1,
             weights=NULL,offset=NULL,Gc=NULL,propodds=1,...)
@@ -78,7 +78,7 @@ cifreg <- function(formula,data=data,cause=1,cens.code=0,cens.model=~1,
     m[[1]] <- as.name("model.frame")
     m <- eval(m, parent.frame())
     Y <- model.extract(m, "response")
-    if (class(Y)!="Event") stop("Expected a 'Event'-object")
+    if (!inherits(Y,"Event")) stop("Expected a 'Event'-object")
     if (ncol(Y)==2) {
         exit <- Y[,1]
         entry <- NULL ## rep(0,nrow(Y))
@@ -121,7 +121,7 @@ cifreg <- function(formula,data=data,cause=1,cens.code=0,cens.model=~1,
                   cluster.pos=pos.cluster,n=nrow(X),nevent=sum(status==cause))
              )
 
-    class(res) <- c("phreg","cif.reg")
+    class(res) <- c("phreg","cifreg")
     return(res)
 }# }}}
 
@@ -133,7 +133,7 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     if (missing(beta)) beta <- rep(0,p)
     if (p==0) X <- cbind(rep(0,length(exit)))
 
-    cause.jumps <- which(status==cause)
+    cause.jumps <- which(status %in% cause)
     max.jump <- max(exit[cause.jumps])
     other <- which((!(status %in% c(cens.code,cause)) ) & (exit< max.jump))
 
@@ -162,6 +162,7 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     if (is.null(case.weights)) case.weights <- rep(1,length(exit))
     strata.call <- strata
 
+    call.id <- id
     if (!is.null(id)) {
         ids <- unique(id)
         nid <- length(ids)
@@ -176,27 +177,24 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
 
     ## }}}
 
-### censoring weights constructed
-    whereC <- which(status==cens.code)
+    ### censoring weights constructed
+    whereC <- which(status %in% cens.code)
     time <- exit
-    statusC <- (status==cens.code)
+    statusC <- (status %in% cens.code)
     data$id <- id
     data$exit <- exit
     data$statusC <- statusC
     cens.strata <- cens.nstrata <- NULL
 
-###	strataC <- model.matrix(cens.model,data)
-###	print(strataC)
-
     if (length(whereC)>0) {# {{{
     if (is.null(Gc)) {
         kmt <- TRUE
-        if (class(cens.model)[1]=="formula") {
+        if (inherits(cens.model,"formula")) {
             formC <- update.formula(cens.model,Surv(exit,statusC)~ . +cluster(id))
             cens.model <- phreg(formC,data)
         }
         if (cens.model$p>0) kmt <- FALSE
-        Pcens.model <- predict(cens.model,data,times=exit,tminus=TRUE,individual.time=TRUE,se=FALSE,km=kmt)
+        Pcens.model <- suppressWarnings(predict(cens.model,data,times=exit,tminus=TRUE,individual.time=TRUE,se=FALSE,km=kmt))
         Stime <- Pcens.model$surv <- c(Pcens.model$surv)
         ## strata from original data
         nCstrata <- cens.model$nstrata
@@ -219,7 +217,7 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
 
     Zcall <- cbind(status,cens.strata,Stime) ## to keep track of status and Censoring strata
     ## setting up all jumps of type "cause", need S0, S1, S2 at jumps of "cause"
-    stat1 <- 1*(status==cause)
+    stat1 <- 1*(status %in% cause)
     trunc <- FALSE
     xx2 <- .Call("FastCoxPrepStrata",entry,exit,stat1,X,id,trunc,strata,weights,offset,Zcall,case.weights,PACKAGE="mets")
     xx2$nstrata <- nstrata
@@ -235,8 +233,9 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
             Gts <- vecAllStrata(cens.model$cumhaz[,2],cens.model$strata.jump,cens.model$nstrata)
             ### back to km product-limit form
             Gts <- apply(rbind(0,Gts),2,diff)
+            if (is.null(dim(Gts))) Gts <- matrix(Gts,1,1)
             ### back to km
-            GtsAl<- Gts <- apply(Gts,2,function(x) exp(cumsum(log(1-x))))
+            Gts <- suppressWarnings(apply(Gts,2,function(x) exp(cumsum(log(1-x)))))
             Gts <- rbind(1,Gts)[whereaJ,]
             Gts[is.na(Gts)] <- 0
             Gjumps <- Gts
@@ -245,7 +244,6 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
         Gts <-   Gjumps <- rep(1,length(jumptimes))
     }
 
-
     ## computing terms for those experiencing another cause, need S0, S1, S2
     if (length(other)>=1) {# {{{
         trunc <- TRUE
@@ -275,7 +273,6 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
 	### gives index of timeo related to jumptimes and same strata
 	### the value 0 means that jumptime has no point in time0, thus S0other=0
         where <- indexstratarightR(timeo,xx$strata,jumptimes,strata1jumptimes,nstrata)
-###	print(cbind(where,strata1jumptimes, strata1jumptimes %in% xx$strata ))
     }# }}}
 
 
@@ -397,15 +394,13 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
         val <- obj(0,all=TRUE)
     }# }}}
 
-
     beta.s <- val$coef
     if (is.null(beta.s)) beta.s <- 0
     ## getting final S's
     opt <-  val ## obj(beta.s,all=TRUE)
 
-
     if (p>0) {
-### iid version given G_c
+    ### iid version given G_c
     ## {{{
     ##iid robust phreg
     S0i <- rep(0,length(xx2$strata))
@@ -423,18 +418,17 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     }
     EdLam0 <- apply(E*S0i,2,cumsumstrata,xx2$strata,xx2$nstrata)
 
-### Martingale  as a function of time and for all subjects to handle strata
+    ### Martingale  as a function of time and for all subjects to handle strata
     MGt <- U[,drop=FALSE]-(Z*cumhaz-EdLam0)*rr*c(xx2$weights)
     mid <- max(xx2$id)
     UU <- apply(MGt,2,sumstrata,xx2$id,mid+1)
 
     if (length(other)>=1) { ## martingale part for type-2 after T
 
-### xx2 data all data
+    ### xx2 data all data
         otherxx2 <- which(!(xx2$Z[,1] %in% c(cause,cens.code)))
-        statusxx2 <- xx2$Z[,1]
         rr0 <- xx2$sign
-        jumpsC <- which(xx2$Z[,1]==cens.code)
+        jumpsC <-  which(xx2$Z[,1] %in% cens.code)
         strataCxx2 <- xx2$Z[,2]
         S0iC2  <-  S0iC <- rep(0,length(xx2$status))
         S0rrr <- revcumsumstrata(rr0,strataCxx2,nCstrata)
@@ -501,8 +495,6 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     if (no.opt==FALSE & p!=0) {
         DLambeta.t <- apply(opt$E/c(opt$S0),2,cumsumstrata,strata,nstrata)
         varbetat <-   rowSums((DLambeta.t %*% iH)*DLambeta.t)
-### covariance is 0 for cox model
-### covv <-  apply(covv*DLambeta.t,1,sum) Covariance is "0" by construction
     } else varbetat <- 0
     var.cumhaz <- cumsumstrata(1/opt$S0^2,strata,nstrata)+varbetat
     se.cumhaz <- cbind(jumptimes,(var.cumhaz)^.5)
@@ -514,10 +506,12 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
                 ihessian=iH,hessian=opt$hessian,var1=var1,se1.coef=diag(var1)^.5,
                 ploglik=opt$ploglik,gradient=opt$gradient,
                 cumhaz=cumhaz, se.cumhaz=se.cumhaz,MGciid=MGc,
+		strata.call=strata.call,
                 strata=xx2$strata, nstrata=nstrata,strata.name=strata.name,strata.level=strata.level,
 		propodds=propodds,
                 S0=opt$S0,E=opt$E,S2S0=opt$S2S0,time=opt$time,Ut=opt$U,
                 jumps=jumps,exit=exit,p=p,
+		id=id.orig,call.id=call.id,
 		no.opt=no.opt,##n=nrow(X),nevent=length(jumps),
                 Pcens.model=Pcens.model,Gjumps=Gjumps,cens.code=cens.code,cause=cause
                 )
@@ -530,34 +524,25 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
 ##' @export
 indexstratarightR <- function(timeo,stratao,jump,js,nstrata,type="right")# {{{
 {
+  if (any(stratao<0 | stratao>=nstrata)) stop("time-strata strata not between 0-(nstrata-1)\n")
+  if (any(js<0 | js>=nstrata)) stop("jump-strata strata not between 0-(nstrata-1)\n")
   mm <- cbind(timeo,stratao,1:length(timeo),0)
   mm <- rbind(mm,cbind(jump,js,1:length(jump),1))
   ord <- order(mm[,1],mm[,4])
   mm <- mm[ord,]
   if (type=="right") right <- 1 else right <- 0
-  res <- .Call("indexstrataR",mm[,2],mm[,3],mm[,4],nstrata,right)$res
-  return(res[,1])
+  res <- .Call("indexstrataR",mm[,2],mm[,3],mm[,4],nstrata,right)$res[,1]
+  if (right==0) res <- rev(res)
+  return(res)
 }# }}}
 
-###S0_FG_Gct <- function(S0,Gct,strata,nstrata,strata2,nstrata2,Gcstart)
-###{# {{{
-###    if (any(strata<0) | any(strata>nstrata-1)) stop("strata index not ok\n");
-###    if (any(strata2<0) | any(strata2>nstrata2-1)) stop("strata2 index not ok\n");
-###    if (length(S0)!=length(strata))  stop("length of x and strata must be same\n");
-###    if (length(S0)!=length(strata2)) stop("length of x and strata2 must be same\n");
-###    if (length(Gct)!=length(S0)) stop("length of S0 and Gct must be same\n");
-###    res <- .Call("S0_FG_GcR",as.double(S0),as.double(Gct),strata,nstrata,strata2,nstrata2,as.double(Gcstart),PACKAGE="mets")$S0
-###    return(res)
-###}# }}}
-
-##' @export
-iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
+##' @export IIDbaseline.cifreg 
+IIDbaseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
 {# {{{
 ###  sum_i int_0^t 1/S_0(s) dM_{ki}(s) - P(t) \beta_k
 ###  with possible strata and cluster "k", and i in clusters 
   if (length(class(x))!=2) stop("Must be cifreg object\n"); 
-  if (class(x)[1]!="phreg") stop("Must be phreg object\n"); 
-  if (class(x)[2]!="cif.reg") stop("Must be cifregobject\n"); 
+  if (!inherits(x,c("cifreg","recreg"))) stop("Must be cifreg object\n"); 
   if (is.null(time)) stop("Must give time for iid of baseline")
 
   if (!is.null(x$propodds))  stop("Only for Fine-Gray-model") 
@@ -573,13 +558,14 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
   btimexx <- c(1*(xx2$time < time))
 
   status <- xx2$Z[,1]
-  cause.jumps <- which(status==x$cause)
+  cause.jumps <- xx2$jumps+1 
   exit <- xx2$time
-  max.jump <- max(exit[cause.jumps])
-  cause <- x$cause
-  cens.code <- x$cens.code
-  other <- which((!(status %in% c(x$cens.code,x$cause)) ) & (exit< max.jump))
-  whereC <- which(status==cens.code)
+  max.jump <- max(exit[cause.jumps])+1
+  if (inherits(x,c("cifreg"))) 
+  other <- which((!(status %in% c(x$cens.code,x$cause)) ) )
+  else 
+  other <- which((status %in% x$death.code) & (xx2$sign==1) )
+  whereC <- which( (status %in% x$cens.code) & xx2$sign==1)
 
   jumps <- xx2$jumps+1
   jumptimes <- xx2$time[jumps]
@@ -590,16 +576,6 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
   nCstrata <- max(strataCxx2)+1
 # }}}
 
-### find id's within different strata
- newid <- mystrata2index(cbind(xx2$strata,xx2$id))
- nnewid <- attr(newid,"nlevel")
- idds <- cbind(newid,xx2$strata,xx2$id)
- on <- order(newid)
- idds <- idds[on,]
- firstnewid <- (!duplicated(idds[,1]))
- strata <- idds[firstnewid,2]
- idstrata <- idds[firstnewid,3]
-
 ### iid version given G_c {{{
     ##iid robust phreg
     S0i <- rep(0,length(xx2$strata))
@@ -611,7 +587,6 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
     cumhazA <- cumsumstratasum(S0i,xx2$strata,xx2$nstrata,type="all")
     cumhaz <- c(cumhazA$sum)
 
-
     if (fixbeta==0) {
 	  EdLam0 <- apply(E*S0i,2,cumsumstrata,xx2$strata,xx2$nstrata)
 	  Ht <- apply(E*S0i*btimexx,2,cumsumstrata,xx2$strata,xx2$nstrata)
@@ -619,7 +594,7 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
   if (fixbeta==0) rr <- c(xx2$sign*exp(Z %*% coef(x) + xx2$offset)) else rr <- c(xx2$sign*exp(xx2$offset))
 
 ### Martingale  as a function of time and for all subjects to handle strata
-    mid <- max(xx2$id)
+   mid <- max(xx2$id)
   if (fixbeta==0)  {
     MGt <- U[,drop=FALSE]-(Z*cumhaz-EdLam0)*rr*c(xx2$weights)
     UU <- apply(MGt,2,sumstrata,xx2$id,mid+1)
@@ -629,17 +604,15 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
     S0i2 <- rep(0,length(xx2$strata))
     S0i2[jumps] <- 1/x$S0^2
     MGAiid <- matrix(0,length(S0i2),1)
+    MGAiid2 <- matrix(0,length(S0i2),1)
     cumhazAA <- cumsumstrata(S0i2*btimexx,xx2$strata,xx2$nstrata)
     MGAiid <- S0i*btimexx-cumhazAA*rr*c(xx2$weights)
-    MGAiid <-  apply(MGAiid,2,sumstrata,newid-1,nnewid)
-###    MGAiid <-  apply(MGAiid,2,sumstrata,xx2$id,mid+1)
 
   if (length(other)>=1) { ## martingale part for type-2 after T
     ### xx2 data all data
-        otherxx2 <- which(!(xx2$Z[,1] %in% c(cause,cens.code)))
-        statusxx2 <- xx2$Z[,1]
+        otherxx2 <- other  
         rr0 <- xx2$sign
-        jumpsC <- which(xx2$Z[,1]==cens.code)
+        jumpsC <- whereC 
         S0iC2  <-  S0iC <- rep(0,length(xx2$status))
         S0rrr <- revcumsumstrata(rr0,strataCxx2,nCstrata)
         S0iC[jumpsC] <- 1/S0rrr[jumpsC]
@@ -651,11 +624,11 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
         ndstrata <- attr(dstrata,"nlevel")
         lastt <- tailstrata(dstrata-1,ndstrata)
         ll <-  cumsum2strata(Gcxx2,S0i,strataCxx2,nCstrata,xx2$strata,xx2$nstrata,Gstart)
-        Htsj <- ll$res[lastt][dstrata]-ll$lagres
+        Htsj <- ll$res[lastt][dstrata]-ll$res
 
         fff <- function(x) {
             cx  <- cumsum2strata(Gcxx2,x*S0i,strataCxx2,nCstrata,xx2$strata,xx2$nstrata,Gstart)
-            cx <- cx$res[lastt][dstrata]-cx$lagres
+            cx <- cx$res[lastt][dstrata]-cx$res
             return(cx)
         }
         EHtsj  <- apply(E,2,fff)
@@ -665,10 +638,8 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
         UU  <-  UU+UU2
 
         ll <-  cumsum2strata(Gcxx2,S0i2*btimexx,strataCxx2,nCstrata,xx2$strata,xx2$nstrata,Gstart)
-        HBtsj <- ll$res[lastt][dstrata]-ll$lagres
-        MGAiid2 <- -HBtsj[otherxx2,,drop=FALSE]*rrx2
-	MGAiid2 <-  apply(MGAiid2,2,sumstrata,newid[otherxx2]-1,nnewid)
-###	MGAiid2 <-  apply(MGAiid2,2,sumstrata,xx2$id[otherxx2],mid+1)
+        HBtsj <- ll$res[lastt][dstrata]-ll$res
+        MGAiid2[otherxx2,] <- -HBtsj[otherxx2,,drop=FALSE]*rrx2
 	MGAiid <- MGAiid+MGAiid2
     }
     ## }}}
@@ -696,16 +667,14 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
         EBdLam0q2 <- apply(qB2,2,fff)
 
         ### Martingale  as a function of time and for all subjects to handle strata
-        MGc <- q2*S0iC-EdLam0q2
+        MGc <- q2*S0iC-EdLam0q2*c(xx2$sign)
         MGc <- apply(MGc,2,sumstrata,xx2$id,mid+1)
 
-        MGBc <- qB2*S0iC-EBdLam0q2
-        MGBc <- apply(MGBc,2,sumstrata,newid-1,nnewid)
+        MGBc <- qB2*S0iC-EBdLam0q2*c(xx2$sign)
         ## }}}
     } else { MGc <- 0; MGBc <- 0}
 
   if (fixbeta==0) { betaiid <-  (UU+MGc) %*% x$ihessian} else betaiid <- NULL
-   MGAiid.naive <- MGAiid
    MGAiid <- MGAiid+MGBc
 
  ### \hat beta - \beta = \sum_i \beta_i  (iid) 
@@ -713,44 +682,63 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
  ### \hat A_s-A_s=\sum_{i clusters} \sum_{j \in i(j)=i, s(j)=s} \int_0^t 1/S_0 dM^s_j - P^s(t) \sum_i \beta_i
  ### = \sum_{i clusters} ( \sum_{j \in i(j)=i, s(j)=s} \int_0^t 1/S_0 dM^s_j - P^s(t) \beta_i ) 
 
- if (fixbeta==0) {
-     Htlast <- tailstrata(xx2$strata,xx2$nstrata)
-     HtS <- Ht[Htlast,,drop=FALSE]
-     UU <-  apply(HtS[strata+1,,drop=FALSE]*betaiid[idstrata+1,],1,sum)
-     MGAiid <- MGAiid - UU
-     MGAiid.naive <- MGAiid.naive - UU
- }
+ if (fixbeta==0) {# {{{
+    Htlast <- tailstrata(xx2$strata,xx2$nstrata)
+    HtS <- Ht[Htlast,,drop=FALSE]
+ } ## }}}
 
- return(list(time=time,base.iid=MGAiid,base.iid.naive=MGAiid.naive,
-	     strata=strata,nstrata=xx2$nstrata,idstrata=idstrata,nid=nnewid,
-	     beta.iid=betaiid,
+
+## sum after id's within strata and order 
+ MGAiids <- c()
+ cumhaz.time <- c()
+ sus <- sort(unique(xx2$strata))
+ for (i in sus)  { 
+	 wi <- which(xx2$strata==i)
+         MGAiidl <- sumstrata(MGAiid[wi],xx2$id[wi],mid+1)
+	 cumhaz.time <- c(cumhaz.time,cpred(x$cumhaz[x$strata[x$jumps]==i,],time)[,-1])
+
+        if (fixbeta==0) {
+           UU <-  apply(HtS[i+1,]*t(betaiid),2,sum)
+           MGAiidl <- MGAiidl - UU
+         }
+         MGAiids <- cbind(MGAiids,MGAiidl)
+ }
+ colnames(MGAiids) <- paste("strata",sus,sep="")
+ names(cumhaz.time) <- paste("strata",sus,sep="")
+
+ return(list(time=time,base.iid=MGAiids, nstrata=xx2$nstrata, beta.iid=betaiid,
+	     strata.call=x$strata.call,id=x$id,call.id=x$call.id,
 	     coef=coef(x),cumhaz=x$cumhaz,cumhaz.strata=x$strata[x$jumps],
+	     cumhaz.time=cumhaz.time,strata.time=sus,
              nstrata=x$nstrata,strata.name=x$strata.name,strata.level=x$strata.level,
 	     model.frame=x$model.frame,formula=x$formula))
 } # }}}
 
 ##' @export
-FGprediid <- function(iidBase,newdata,conf.type=c("log","cloglog","plain"))
+FGprediid <- function(iidBase,newdata,conf.type=c("log","cloglog","plain"),model="FG")
 {# {{{
   des <- readPhreg(iidBase,newdata)
   strata <- des$strata
-  if (!is.null(iidBase$beta.iid))  { fixbeta <- 0; beta.iid <- iidBase$beta.iid; X <- des$X} else { 
-	  fixbeta <- 1; beta.iid <- 0; X <- matrix(0,1,1); }
+  if (!is.null(iidBase$beta.iid))  { 
+	  fixbeta <- 0; beta.iid <- iidBase$beta.iid; X <- des$X; p <- ncol(beta.iid); 
+  } else { fixbeta <- 1; beta.iid <- 0; X <- matrix(0,1,1); p <- 1 }
 
-   At <- c()
-   for (i in sort(unique(strata))) {
-   At <- c(At,Cpred(iidBase$cumhaz[iidBase$cumhaz.strata==i,],iidBase$time)[,-1])
-   }
-   p <- length(iidBase$coef)
+   sus <- sort(unique(strata))
+
+   At <- iidBase$cumhaz.time[match(sus,iidBase$strata.time)]
 
    if (missing(X)) X <- matrix(0,1,p)
    if (ncol(X)!=p) stop("X and coef does not match \n"); 
 
-
    Ft <- function(p,Xi=rep(0,length(p)-1),type="log") {
+   if (model=="FG") {
        if (type=="log")     y <- log(1-exp(-p[1]*exp(sum(Xi*p[-1]))))
        if (type=="plain")   y <- 1-exp(-p[1]*exp(sum(Xi*p[-1])))
        if (type=="cloglog") y <- log(-log(1-exp(-p[1]*exp(sum(Xi*p[-1])))))
+   } else { ## Ghosh-Lin model
+       if (type=="log")     y <- log(p[1]*exp(sum(Xi*p[-1])))
+       if (type=="plain")   y <- p[1]*exp(sum(Xi*p[-1]))
+   }
        return(y)
    }
    Ftback <- function(p,type="log")
@@ -761,37 +749,37 @@ FGprediid <- function(iidBase,newdata,conf.type=c("log","cloglog","plain"))
        return(y)
    }
 
-preds <- matrix(0,length(strata),4)
+   preds <- matrix(0,length(strata),4)
 
-k <- 0
-for (i in sort(unique(strata))) {
-   k <- k+1
-   wheres <- which(strata==i) 
-if (fixbeta==0)  {
-   iidAB <- cbind(iidBase$base.iid,iidBase$beta.iid)[iidBase$strata==i,]
-   covv <- crossprod(iidAB)
-   coeff <- c(At[k],iidBase$coef)
-   Xs <- X[wheres,,drop=FALSE]
-   for (j in seq(1,nrow(Xs)))  {
-      Xj <- Xs[j,]
-      eud <- estimate(coef=coeff,vcov=covv,f=function(p) Ft(p,Xi=Xj,type=conf.type[1]))
-      cmat <- eud$coefmat
-      cmat <- c(cmat[,-5])
-      cicmat <- Ftback(cmat[c(1,3:4)],type=conf.type[1])
-      cmat[c(1,3:4)] <- cicmat
-      preds[wheres[j],] <- c(cmat)
-   } 
-} else {
-      iidAB <- cbind(iidBase$base.iid)[iidBase$strata==i,]
-      covv <- crossprod(iidAB)
-      coeff <- c(At[k])
-      eud <- estimate(coef=coeff,vcov=covv,f=function(p) Ft(p,Xi=1,type=conf.type[1]))
-      cmat <- eud$coefmat
-      cmat <- c(cmat[,-5])
-      cicmat <- Ftback(cmat[c(1,3:4)],type=conf.type[1])
-      cmat[c(1,3:4)] <- cicmat
-      preds[wheres,] <- matrix(c(cmat),length(wheres),4,byrow=TRUE)
-}
+   k <- 0
+   for (i in sus) {
+      wheres <- which(strata==i) 
+      wi <- match(i,iidBase$strata.time)
+      At <- iidBase$cumhaz.time[wi]
+	if (fixbeta==0)  {
+	   iidAB <- cbind(iidBase$base.iid[,wi],iidBase$beta.iid)
+	   covv <- crossprod(iidAB)
+	   coeff <- c(At,iidBase$coef)
+	   for (j in wheres)  {
+	      Xj <- X[j,]
+	      eud <- estimate(coef=coeff,vcov=covv,f=function(p) Ft(p,Xi=Xj,type=conf.type[1]))
+	      cmat <- eud$coefmat
+	      cmat <- c(cmat[,-5])
+	      cicmat <- Ftback(cmat[c(1,3:4)],type=conf.type[1])
+	      cmat[c(1,3:4)] <- cicmat
+	      preds[j,] <- c(cmat)
+	   } 
+	} else {
+	      iidAB <- cbind(iidBase$base.iid[,wi])
+	      covv <- crossprod(iidAB)
+	      coeff <- c(At)
+	      eud <- estimate(coef=coeff,vcov=covv,f=function(p) Ft(p,Xi=1,type=conf.type[1]))
+	      cmat <- eud$coefmat
+	      cmat <- c(cmat[,-5])
+	      cicmat <- Ftback(cmat[c(1,3:4)],type=conf.type[1])
+	      cmat[c(1,3:4)] <- cicmat
+	      preds[wheres,] <- matrix(c(cmat),length(wheres),4,byrow=TRUE)
+	}
 }
 
 colnames(preds) <- c("pred",paste("se",conf.type[1],sep="-"),"lower","upper")
@@ -866,7 +854,7 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     m[[1]] <- as.name("model.frame")
     m <- eval(m, parent.frame())
     Y <- model.extract(m, "response")
-    if (class(Y)!="Event") stop("Expected a 'Event'-object")
+    if (!inherits(Y,"Event")) stop("Expected a 'Event'-object")
     if (ncol(Y)==2) {
         exit <- Y[,1]
         entry <- NULL ## rep(0,nrow(Y))
@@ -996,8 +984,8 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     xxstatus  <- dd$Z[,1]
     xxstrata  <- dd$Z[,2]
     other <- which((!(xxstatus %in% c(cens.code,cause)) ) )
-    jumps1 <- which(xxstatus==cause)
-    jumpsD <- which(xxstatus!=cens.code)
+    jumps1 <- which(xxstatus %in% cause)
+    jumpsD <- which(!(xxstatus %in% cens.code))
     rr <- c(dd$sign*exp(dd$offset))
     ## S0 after strata
     S0 = c(revcumsumstrata(rr,xxstrata,nstrata))
@@ -1059,7 +1047,7 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     ndstrata <- attr(dstrata,"nlevel")
     lastt <- tailstrata(dstrata-1,ndstrata)
 
-### ## \int_t^\infty G_c^j(t) d\Lambda_1^k(t)
+    ### ## \int_t^\infty G_c^j(t) d\Lambda_1^k(t)
     G0start <- rep(1,nstrataC)
     cLam1fg  <- cumsum2strata(Gc,dLam1fg,xxstrataC,nstrataC,xxstrata,nstrata,G0start)
     RLam1fg <- cLam1fg$res[lastt][dstrata]-cLam1fg$res
@@ -1094,7 +1082,7 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     U1[jumps,] <- gt[jumps]
     U2[jumps,] <- ERLam1fg[jumps,]
 
-### Martingale  as a function of time and for all subjects to handle strata
+    ### Martingale  as a function of time and for all subjects to handle strata
     MG1t <- Z*c(U1[,,drop=FALSE]-E1dLam0)*rr*c(dd$weights)
     MG2t <- (U2[,,drop=FALSE]-E2dLam0)*rr*c(dd$weights)
     MGt <- MG1t-MG2t
@@ -1102,7 +1090,6 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     augment <- apply(MGt,2,sum)
 
     augment <- list(MGiid=MGiid,augment=augment,id=id,id.orig=id.orig,
-###     dd=dd,Et=Et,E=E, gt=gt, ERLam1fg=ERLam1fg,RLam1fg=RLam1fg,ERLam1fg0=ERLam1fg0,
                     jumps1=jumps1,jumps=jumps,other=other,
                     nstrata=nstrata,nstrataC=nstrataC,dstrata=dstrata,ndstrata=ndstrata,
                     cif1=cif1,cif2=cif2,St=St,Gc=Gc,strata=xxstrata,strataC=xxstrataC,time=dd$time)
@@ -1134,8 +1121,7 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
 
 
 ##' @export
-simul.cifs <- function(n,rho1,rho2,beta,rc=0.5,depcens=0,rcZ=0.5,bin=1,
-                type=c("cloglog","logistic"),rate=1) {# {{{
+simul.cifs <- function(n,rho1,rho2,beta,rc=0.5,depcens=0,rcZ=0.5,bin=1,type=c("cloglog","logistic"),rate=1,Z=NULL) {# {{{
     p=length(beta)/2
     tt <- seq(0,6,by=0.1)
     if (length(rate)==1) rate <- rep(rate,2)
@@ -1143,16 +1129,18 @@ simul.cifs <- function(n,rho1,rho2,beta,rc=0.5,depcens=0,rcZ=0.5,bin=1,
     Lam2 <- rho2*(1-exp(-tt/rate[2]))
 
     if (length(bin)==1) bin <- rep(bin,2)
+    if (length(rcZ)==1) rcZ <- c(rcZ,0)
 
+    if (is.null(Z)) 
     Z=cbind((bin[1]==1)*(2*rbinom(n,1,1/2)-1)+(bin[1]==0)*rnorm(n),(bin[2]==1)*(rbinom(n,1,1/2))+(bin[2]==0)*rnorm(n))
     colnames(Z) <- paste("Z",1:2,sep="")
+    p <- ncol(Z)
 
-    cif1 <- setup.cif(cbind(tt,Lam1),beta[1:2],Znames=colnames(Z),type=type[1])
-    cif2 <- setup.cif(cbind(tt,Lam2),beta[3:4],Znames=colnames(Z),type=type[1])
-###
-    data <- timereg::sim.cifsRestrict(list(cif1,cif2),n,Z=Z)
+    cif1 <- setup.cif(cbind(tt,Lam1),beta[1:p],Znames=colnames(Z),type=type[1])
+    cif2 <- setup.cif(cbind(tt,Lam2),beta[(p+1):(2*p)],Znames=colnames(Z),type=type[1])
+    data <- sim.cifsRestrict(list(cif1,cif2),n,Z=Z)
 
-    if (depcens==0) censor=pmin(rexp(n,1)*(1/rc),6) else censor=pmin(rexp(n,1)*(1/(rc*exp(rcZ*Z[,1]))),6)
+    if (depcens==0) censor=pmin(rexp(n,1)*(1/rc),6) else censor=pmin(rexp(n,1)*(1/(rc*exp(Z %*% rcZ))),6)
 
     status=data$status*(data$time<=censor)
     time=pmin(data$time,censor)
@@ -1171,7 +1159,6 @@ simul.mod <- function(n,rho1,rho2,beta,rc=0.5,k=1,depcens=0) {# {{{
     colnames(Z) <- paste("Z",1:2,sep="")
     cif1 <- setup.cif(cbind(tt,Lam1),beta[1:2],Znames=colnames(Z),type="cloglog")
     cif2 <- setup.cif(cbind(tt,Lam2),beta[3:4],Znames=colnames(Z),type="cloglog")
-###
     data <- sim.cifsRestrict(list(cif1,cif2),n,Z=Z)
 
     censhaz  <-  cbind(tt,k*tt)
