@@ -11,7 +11,7 @@ library(mets)
  set.seed(1000) # to control output in simulatins for p-values below.
 
  rho1 <- 0.2; rho2 <- 10
- n <- 4000
+ n <- 400
  beta=c(0.0,-0.1,-0.5,0.3)
  ## beta1=c(0.0,-0.1); beta2=c(-0.5,0.3)
  dats <- simul.cifs(n,rho1,rho2,beta,rc=0.5,rate=7)
@@ -37,7 +37,7 @@ library(mets)
 ## -----------------------------------------------------------------------------
 ### predictions with CI based on iid decomposition of baseline and beta
 fg <- cifreg(Event(time,status)~Z1+Z2,data=dats,cause=1,propodds=NULL,cox.prep=TRUE)
-Biid <- mets:::iid.baseline.cifreg(fg,time=5)
+Biid <- IIDbaseline.cifreg(fg,time=5)
 pfgse <- FGprediid(Biid,dd)
 pfgse
 plot(pfg,ylim=c(0,0.2))
@@ -50,18 +50,41 @@ if (run==1) {
  mm <- model.matrix(~Z1+Z2,dats)[,-1]
  cr <- with(dats,crr(time,status,mm))
  cbind(cr$coef,diag(cr$var)^.5,fg$coef,fg$se.coef,cr$coef-fg$coef,diag(cr$var)^.5-fg$se.coef)
+#          [,1]      [,2]       [,3]      [,4]          [,5]          [,6]
+# Z1  0.6968603 0.3876029  0.6968603 0.3876029 -1.534155e-09 -7.811395e-10
+# Z2 -0.8592892 0.6245258 -0.8592892 0.6245258  8.537615e-14  4.430734e-11
 }
-#           [,1]       [,2]        [,3]       [,4]         [,5]          [,6]
-# Z1  0.06882201 0.08184642  0.06882199 0.08184642 1.398233e-08 -9.805955e-11
-# Z2 -0.36807861 0.16606441 -0.36807951 0.16606444 9.045060e-07 -2.529264e-08
 
 if (run==1) {
  fg0 <- cifreg(Event(time,status)~Z1+Z2,data=dats,cause=1,propodds=NULL,beta=cr$coef,no.opt=TRUE)
  cbind(diag(cr$var)^.5,fg0$se.coef,diag(cr$var)^.5-fg0$se.coef)
+#           [,1]      [,2]          [,3]
+# [1,] 0.3876029 0.3876029 -8.881784e-16
+# [2,] 0.6245258 0.6245258  3.330669e-16
 }
-#            [,1]       [,2]          [,3]
-# [1,] 0.08184642 0.08184642 -8.975096e-11
-# [2,] 0.16606441 0.16606441 -1.091264e-10
+
+## -----------------------------------------------------------------------------
+if (run==1) {
+ dats$id <- 1:nrow(dats)
+ dats$event <- factor(dats$status,0:2, labels=c("censor", "death", "other"))
+ fgdats <- finegray(Surv(time,event)~.,data=dats)
+ coxfg <- coxph(Surv(fgstart, fgstop, fgstatus) ~ Z1+Z2 + cluster(id), weight=fgwt, data=fgdats)
+
+ fg0 <- cifreg(Event(time,status)~Z1+Z2,data=dats,cause=1,propodds=NULL)
+ cbind( coxfg$coef,fg0$coef, coxfg$coef-fg0$coef)
+#          [,1]       [,2]          [,3]
+# Z1  0.6968603  0.6968603 -1.534153e-09
+# Z2 -0.8592892 -0.8592892  8.726353e-14
+ cbind(diag(coxfg$var)^.5,fg0$se.coef,diag(coxfg$var)^.5-fg0$se.coef)
+#           [,1]      [,2]          [,3]
+# [1,] 0.3889129 0.3876029  0.0013099907
+# [2,] 0.6241225 0.6245258 -0.0004033148
+ cbind(diag(coxfg$var)^.5,fg0$se1.coef,diag(coxfg$var)^.5-fg0$se1.coef)
+#           [,1]      [,2]          [,3]
+# [1,] 0.3889129 0.3889129 -7.839487e-10
+# [2,] 0.6241225 0.6241225  4.448153e-11
+}
+
 
 ## -----------------------------------------------------------------------------
 datsnc <- dtransform(dats,status=2,status==0)
@@ -86,10 +109,10 @@ if (run==1) {
  mm <- model.matrix(~Z1+Z2,datsnc)[,-1]
  cr <- with(datsnc,crr(time,status,mm))
  cbind(cifnc$coef-cr$coef, diag(cr$var)^.5-cifnc$se.coef)
+#            [,1]          [,2]
+# Z1 2.053291e-09 -1.048037e-09
+# Z2 1.926237e-13  7.571876e-11
 }
-#             [,1]          [,2]
-# Z1  1.194188e-10 -6.742754e-11
-# Z2 -8.828051e-07 -2.488335e-08
 
 ## -----------------------------------------------------------------------------
  fgcm <- cifreg(Event(time,status)~Z1+Z2,data=dats,cause=1,propodds=NULL,
@@ -109,7 +132,7 @@ if (run==1) {
 
 ## -----------------------------------------------------------------------------
  rho1 <- 0.2; rho2 <- 10
- n <- 4000
+ n <- 400
  beta=c(0.0,-0.1,-0.5,0.3)
  dats <- simul.cifs(n,rho1,rho2,beta,rc=0.5,rate=7,type="logistic")
  dtable(dats,~status)
